<?php
/*
Plugin Name: CookieMonster-plus
Plugin URI: http://mercs.net/cookiemonster-plus/
Description: Define which URL parameters should be captured, and then creates a shortcode so that the value can be used in your Posts. Based on original CookieMonster plugin by gsmith.
Author: Wayne Buckhanan
Version: 1.3.4
Author URI: http://mercs.net/
License: GPL2 
*/

/* 
This program is free software; you can redistribute it and/or modify 
it under the terms of the GNU General Public License, version 2, as 
published by the Free Software Foundation. 

This program is distributed in the hope that it will be useful, but 
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
for more details. You should have received a copy of the GNU General 
Public License along with this program; if not, write to the 

Free Software Foundation, Inc.
51 Franklin St, Fifth Floor
Boston, MA 02110-1301 USA
*/ 

/*
20101201: v.1.3.4
	Found and squashed that pesky " Invalid argument supplied for foreach()" bug
	Made shortcodes show up on templated pages that didn't use get_header()
20101004: v.1.3.3 
	*** All parameter/cookie names will need to be re-entered if you upgrade from 1.2.X ***
	*** (This should be the last time that is needed barring another major re-write.)   ***
	Added option prefix CMp_ to avoid option name space collisions
20101001: v.1.3.2
	Added function name prefix CMp_ to avoid name space collisions
20100930: v.1.3.1
	Unbroke cookie setting code from refactoring (Oops)
20100929: v.1.3 !! Not backward compatible with 1.2.X !!
	*** All parameter/cookie names will need to be re-entered if you upgrade from 1.2.X ***
	Changed options format to allow blank options to just disappear
20100928: v1.2.2
	Verboten list -- avoid WP reserved names that may break the page (404, etc)
	Turn on shortcodes in widgets [and titles?]
	Wrap short codes in <p> tags with wpautop()
20100927: v1.2.1
	Encode HTML special characters in variables before displaying (to deter malicious code injection)
20100926: v1.2
	Added default values
	Cleaned up original CookieMonster code
	Now allows for more than 4 parameters
	Added "Settings" link to plugin admin screen
*/

/* TODO:
	add cookie duration to options screen
	ability to delete CM+ parameters
*/

function CMp_init_cookies()
{
	global $g_refcode ;
    $cookies = CMp_getcookies();
    foreach($cookies as $cookie => $default)  
	{
        $g_refcode=$_COOKIE[$cookie];
		if( strlen($_GET[$cookie])>0 )
		{
			setcookie($cookie, $_GET[$cookie], time()+60*60*24*30, COOKIEPATH, COOKIE_DOMAIN);
			$g_refcode=$_GET[$cookie];
			$_COOKIE[$cookie]=$g_refcode;
			//unset($_GET[$cookie]); // too late, WP has already borked by now if param name was reserved...
		}
    }     
}
add_action('init', 'CMp_init_cookies');

function CMp_getcookies()
{
    return get_option("CMp_cookie_list");
}

function CMp_shortcode_handler($atts,$content,$code)
{
    $cookies = CMp_getcookies();
    foreach($cookies as $cookie => $default)
	{
        if ($cookie==$code) 
		{
			$retval = isset($_COOKIE[$code]) ? $_COOKIE[$code] : $default;
		}
    }
	return htmlspecialchars($retval);
}

// Install the shortcode handler for each parameter saved in the WP options table
if( $cookies = CMp_getcookies() )
{
	foreach($cookies as $cookie => $default)
	{
		add_shortcode($cookie, 'CMp_shortcode_handler');    
	}
}

// turn on shortcodes in widgets
if (!is_admin()) add_filter('widget_text', 'do_shortcode', 11);
if (!is_admin()) add_filter('widget_title', 'do_shortcode', 11);
// auto <p> the text after it's been filtered for shortcodes
if (!is_admin()) add_filter('the_content', 'wpautop', 12);

// broken?!?
// turn on shortcode processing in page/post titles
if (!is_admin()) add_filter('the_title', 'do_shortcode', 11);
if (!is_admin()) add_filter('wp_title', 'do_shortcode', 11);

// end shortcode install

function CMp_addPluginToSubmenu()   
{  
     add_options_page("CookieMonster-plus Options", "CookieMonster-plus", 1, "CookieMonster-plus", "CMp_admin");
}
add_action('admin_menu', 'CMp_addPluginToSubmenu');  


/**
 * Add Settings link to plugins - code from http://www.whypad.com/posts/wordpress-add-settings-link-to-plugins-page/785/
 */
function CMp_add_settings_link($links, $file) 
{
	static $this_plugin;
	if (!$this_plugin) $this_plugin = plugin_basename(__FILE__);

	if ($file == $this_plugin)
	{
		$settings_link = '<a href="options-general.php?page=CookieMonster-plus">'.__( "Settings", 'cookie_trdom' ).'</a>';
		array_unshift($links, $settings_link);
	}
	
	return $links;
}
add_filter('plugin_action_links', 'CMp_add_settings_link', 10, 2 );

 
function CMp_admin()
{
	$numcookies = $_POST["numcookies"];
    if($_POST['update_cookies'] == 'Y') {
        for($x=1; $x <= $numcookies; $x++)
		{
			$cookie_list[$_POST["cookie_param".$x]] = $_POST["cookie_default".$x];
		}
		update_option("CMp_cookie_list", $cookie_list);
		?>
        <div class="updated"><p><strong><?php _e('Options saved.', 'cookie_trdom' ); ?></strong></p></div>
        <?php
    } else { 
        //Normal page display
        for($x=1; $x <= $numcookies; $x++)
		{
			//eval('$cookie'.$x.' = get_option("cookie_param'.$x.'");');
			//eval('$cookie'.$x.' = get_option("cookie_param'.$x.'");');
		}
    }
    
?>

<div class="wrap">
<?php    echo "<h2>" . __( 'CookieMonster-plus Options', 'cookie_trdom' ) . "</h2>"; $x=1 ?>

<form name="cookie_form" method="post" action="<?php echo str_replace( '%7E', '~', $_SERVER['REQUEST_URI']); ?>">
    <input type="hidden" name="update_cookies" value="Y">
<?php    echo "<h4>" . __( 'CookieMonster-plus', 'cookie_trdom' ) . "</h4>";
    _e( 'Enter new parameters to track (i.e. affcode) and click "Update Options".<br/>Leave the Parameter field empty and click "Update Options" to delete it.<br/>Default values will appear when the shortcode (i.e. [affcode]) is used and no cookie value has been set.', 'cookie_trdom' );
    //$cookies=CMp_getcookies();
	if( $cookies = CMp_getcookies() )
	{
		foreach($cookies as $cookie => $default)
		{
			if($cookie)
			{
				echo "<p> URL Parameter ".$x." : <input type='text' name='cookie_param".$x."' value='".$cookie."' size='20'> defaults to <input type='text' name='cookie_default".$x."' value='".$default."' size='20'> Your cookie is currently set to ".$_COOKIE[$cookie]."</p>\n";
				$x++;
			}
		}
	}
	echo "<p> URL Parameter ".$x." : <input type='text' name='cookie_param".$x."' size='20'> defaults to <input type='text' name='cookie_default".$x."' size='20'></p>\n";
	echo "<input type='hidden' name='numcookies' value='$x'>\n";
    ?>
    <p class="submit">
    <input type="submit" name="Submit" value="<?php _e( 'Update Options', 'cookie_trdom' ) ?>" />
    </p>
</form>
<hr/>
<h4><?php _e( 'Do not use these as parameter names:', 'cookie_trdom' ); ?></h4>
<p>They are not likely to do what you want them to do. Expect a 404 error page if you use them.
<ul>
<li>author
<li>author_name
<li>caller_get_posts
<li>cat
<li>category_name
<li>category__and
<li>category__in
<li>category__not_in
<li>day
<li>hour
<li>meta_compare
<li>meta_key
<li>meta_value
<li>minute
<li>monthnum
<li>name
<li>nopaging
<li>order
<li>orderby
<li>p
<li>paged
<li>pagename
<li>page_id
<li>posts_per_page
<li>post_parent
<li>post_status
<li>post_type
<li>post__in
<li>post__not_in
<li>second
<li>showposts
<li>tag
<li>tag_id
<li>tag_slug__and
<li>tag_slug__in
<li>tag__and
<li>tag__in
<li>tag__not_in
<li>w
<li>year
</ul>
</p>
</div>
<?php
}

?>